pub struct ConsumerClient<S = DefaultGrpcImpl> { /* private fields */ }google only.Expand description
A client through which PubSub consuming operations can be performed.
This includes managing subscriptions and reading data from subscriptions. Created using
build_consumer
Implementations
Sourceimpl<S> ConsumerClient<S>
impl<S> ConsumerClient<S>
Sourcepub fn from_client(
client: SubscriberClient<S>,
project: String,
queue: String,
) -> Self
pub fn from_client( client: SubscriberClient<S>, project: String, queue: String, ) -> Self
Create a new consumer from an existing pubsub client.
This function is useful for client customization; most callers should typically use the
defaults provided by build_consumer
Sourcepub fn format_subscription(
&self,
subscription: SubscriptionName<'_>,
) -> ProjectSubscriptionName
pub fn format_subscription( &self, subscription: SubscriptionName<'_>, ) -> ProjectSubscriptionName
Construct a fully formatted project and subscription name for the given subscription
Sourcepub fn format_topic(&self, topic: TopicName<'_>) -> ProjectTopicName
pub fn format_topic(&self, topic: TopicName<'_>) -> ProjectTopicName
Construct a fully formatted project and topic name for the given topic
Sourcepub fn inner(&self) -> &SubscriberClient<S>
pub fn inner(&self) -> &SubscriberClient<S>
Get a reference to the underlying pubsub client
Sourcepub fn inner_mut(&mut self) -> &mut SubscriberClient<S>
pub fn inner_mut(&mut self) -> &mut SubscriberClient<S>
Get a mutable reference to the underlying pubsub client
Sourceimpl<S> ConsumerClient<S>where
S: GrpcService<BoxBody>,
S::Error: Into<StdError>,
S::ResponseBody: Body<Data = Bytes> + Send + 'static,
<S::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<S> ConsumerClient<S>where
S: GrpcService<BoxBody>,
S::Error: Into<StdError>,
S::ResponseBody: Body<Data = Bytes> + Send + 'static,
<S::ResponseBody as Body>::Error: Into<StdError> + Send,
Sourcepub async fn create_subscription(
&mut self,
config: SubscriptionConfig<'_>,
) -> Result<(), PubSubError>
pub async fn create_subscription( &mut self, config: SubscriptionConfig<'_>, ) -> Result<(), PubSubError>
Create a new PubSub subscription
See the GCP documentation on subscriptions here
Sourcepub async fn delete_subscription(
&mut self,
subscription: SubscriptionName<'_>,
) -> Result<(), PubSubError>
pub async fn delete_subscription( &mut self, subscription: SubscriptionName<'_>, ) -> Result<(), PubSubError>
Delete an existing PubSub subscription.
See the GCP documentation on subscriptions here
Sourcepub fn stream_subscription(
&mut self,
subscription: SubscriptionName<'_>,
stream_config: StreamSubscriptionConfig,
) -> PubSubStream<S>where
S: Clone,
pub fn stream_subscription(
&mut self,
subscription: SubscriptionName<'_>,
stream_config: StreamSubscriptionConfig,
) -> PubSubStream<S>where
S: Clone,
Connect to PubSub and start streaming messages from the given subscription
Sourcepub async fn seek(
&mut self,
subscription: SubscriptionName<'_>,
timestamp: Timestamp,
) -> Result<(), PubSubError>
pub async fn seek( &mut self, subscription: SubscriptionName<'_>, timestamp: Timestamp, ) -> Result<(), PubSubError>
Seeks messages from the given timestamp. It marks as acknowledged all the messages prior to the timestamp, and as not acknowledged the messages after the timestamp.